==> kmonad-0.4.4-80.1-loong64.pkg.tar.zst: usr/share/haskell/register/kmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kmonad
version:              0.4.4
visibility:           public
id:                   kmonad-0.4.4-DJdO5OnC34ZCBXtjIMR4dP
key:                  kmonad-0.4.4-DJdO5OnC34ZCBXtjIMR4dP
license:              MIT
maintainer:           janssen.dhj@gmail.com
author:               David Janssen
synopsis:             Advanced keyboard remapping utility
description:
    KMonad is a cross-platform command-line utility that runs as a daemon. It
    captures keyboard input (exactly how depends on the OS) and remaps it. The
    mapping is highly configurable, and provides options like (transparent) layer
    overlays, tap-mod buttons, multi-tap buttons, leader-key style buttons, and
    keyboard macros. Functionality heavily inspired by the QMK-firmware.

category:             Application
abi:                  42be44dc8889377aa009ef0440cb3b9a
exposed:              True
exposed-modules:
    KMonad.App KMonad.App.Main KMonad.App.Types KMonad.Args
    KMonad.Args.Cmd KMonad.Args.Joiner KMonad.Args.Parser
    KMonad.Args.TH KMonad.Args.Types KMonad.Gesture KMonad.Keyboard
    KMonad.Keyboard.ComposeSeq KMonad.Keyboard.IO
    KMonad.Keyboard.IO.Linux.DeviceSource
    KMonad.Keyboard.IO.Linux.Types KMonad.Keyboard.IO.Linux.UinputSink
    KMonad.Keyboard.IO.Mac.Types KMonad.Keyboard.IO.Windows.Types
    KMonad.Keyboard.Keycode KMonad.Keyboard.Ops KMonad.Keyboard.Types
    KMonad.Model KMonad.Model.Action KMonad.Model.BEnv
    KMonad.Model.Button KMonad.Model.Dispatch KMonad.Model.Hooks
    KMonad.Model.Keymap KMonad.Model.Sluice KMonad.Parsing
    KMonad.Prelude KMonad.Prelude.Definitions KMonad.Prelude.Imports
    KMonad.Util KMonad.Util.LayerStack KMonad.Util.MultiMap
    Paths_kmonad

import-dirs:          /usr/lib/ghc-9.6.6/site-local/kmonad-0.4.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/kmonad-0.4.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/kmonad-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/kmonad
hs-libraries:         HSkmonad-0.4.4-DJdO5OnC34ZCBXtjIMR4dP
depends:
    base-4.18.2.1 cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9 mtl-2.3.1
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx
    rio-0.1.22.0-2S3DgnoH0cl6ZJdvxjSsI5 template-haskell-2.20.0.0
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd

haddock-interfaces:   /usr/share/doc/kmonad/html/kmonad.haddock
haddock-html:         /usr/share/doc/kmonad/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> kmonad-0.4.4-81-loong64.pkg.tar.zst: usr/share/haskell/register/kmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kmonad
version:              0.4.4
visibility:           public
id:                   kmonad-0.4.4-3lHd9Lqlf9sB9pMQyhbkAR
key:                  kmonad-0.4.4-3lHd9Lqlf9sB9pMQyhbkAR
license:              MIT
maintainer:           janssen.dhj@gmail.com
author:               David Janssen
synopsis:             Advanced keyboard remapping utility
description:
    KMonad is a cross-platform command-line utility that runs as a daemon. It
    captures keyboard input (exactly how depends on the OS) and remaps it. The
    mapping is highly configurable, and provides options like (transparent) layer
    overlays, tap-mod buttons, multi-tap buttons, leader-key style buttons, and
    keyboard macros. Functionality heavily inspired by the QMK-firmware.

category:             Application
abi:                  8a286380013dc1a2f8b20719dd0e7aca
exposed:              True
exposed-modules:
    KMonad.App KMonad.App.Main KMonad.App.Types KMonad.Args
    KMonad.Args.Cmd KMonad.Args.Joiner KMonad.Args.Parser
    KMonad.Args.TH KMonad.Args.Types KMonad.Gesture KMonad.Keyboard
    KMonad.Keyboard.ComposeSeq KMonad.Keyboard.IO
    KMonad.Keyboard.IO.Linux.DeviceSource
    KMonad.Keyboard.IO.Linux.Types KMonad.Keyboard.IO.Linux.UinputSink
    KMonad.Keyboard.IO.Mac.Types KMonad.Keyboard.IO.Windows.Types
    KMonad.Keyboard.Keycode KMonad.Keyboard.Ops KMonad.Keyboard.Types
    KMonad.Model KMonad.Model.Action KMonad.Model.BEnv
    KMonad.Model.Button KMonad.Model.Dispatch KMonad.Model.Hooks
    KMonad.Model.Keymap KMonad.Model.Sluice KMonad.Parsing
    KMonad.Prelude KMonad.Prelude.Definitions KMonad.Prelude.Imports
    KMonad.Util KMonad.Util.LayerStack KMonad.Util.MultiMap
    Paths_kmonad

import-dirs:          /usr/lib/ghc-9.6.6/site-local/kmonad-0.4.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/kmonad-0.4.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/kmonad-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/kmonad
hs-libraries:         HSkmonad-0.4.4-3lHd9Lqlf9sB9pMQyhbkAR
depends:
    base-4.18.2.1 cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE mtl-2.3.1
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs
    rio-0.1.22.0-9YWPFaDDA8QAvZjRU1ibSo template-haskell-2.20.0.0
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2

haddock-interfaces:   /usr/share/doc/kmonad/html/kmonad.haddock
haddock-html:         /usr/share/doc/kmonad/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
